==> VirtualBoxSDK-4.2.18-88780.zip: org/virtualbox_4_2/jaxws/IMachineSetVideoCaptureWidth.java <==

package org.virtualbox_4_2.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="VideoCaptureWidth" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "videoCaptureWidth"
})
@XmlRootElement(name = "IMachine_setVideoCaptureWidth")
public class IMachineSetVideoCaptureWidth {

    @XmlElement(required = true)
    protected String _this;
    @XmlElement(name = "VideoCaptureWidth")
    @XmlSchemaType(name = "unsignedInt")
    protected long videoCaptureWidth;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the videoCaptureWidth property.
     * 
     */
    public long getVideoCaptureWidth() {
        return videoCaptureWidth;
    }

    /**
     * Sets the value of the videoCaptureWidth property.
     * 
     */
    public void setVideoCaptureWidth(long value) {
        this.videoCaptureWidth = value;
    }

}

==> VirtualBoxSDK-5.0.10-104061.zip: org/virtualbox_5_0/jaxws/IMachineSetVideoCaptureWidth.java <==

package org.virtualbox_5_0.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="videoCaptureWidth" type="{http://www.w3.org/2001/XMLSchema}unsignedInt"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "videoCaptureWidth"
})
@XmlRootElement(name = "IMachine_setVideoCaptureWidth")
public class IMachineSetVideoCaptureWidth {

    @XmlElement(required = true)
    protected String _this;
    @XmlSchemaType(name = "unsignedInt")
    protected long videoCaptureWidth;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the videoCaptureWidth property.
     * 
     */
    public long getVideoCaptureWidth() {
        return videoCaptureWidth;
    }

    /**
     * Sets the value of the videoCaptureWidth property.
     * 
     */
    public void setVideoCaptureWidth(long value) {
        this.videoCaptureWidth = value;
    }

}
